function f = interpol_lag(x, t, Ts)
% INTERPOL_LAG   Interpolation using Lagrange polynomials
%    f = INTERPOL_LAG(x, t, Ts) creates a continuous-time signal x(t) by
%    interpolating the sequence x[n] using Lagrange polynomials. Ts is the
%    sampling time to be used.

% $Id: interpol_lag.m 673 2007-11-22 09:35:29Z kleiner $

% Find N and make sure that it is an integer (i.e., that x is of length
% 2N+1).
N = (length(x) - 1) / 2;
assert(N == floor(N));

% Compute the interpolation from the formula seen in class (10.33).
f = zeros(size(t));
for k = -N:N
    f = f + x(k + N + 1)*lagrange(t, k, N, Ts);
end
